@@ -16,10 +16,10 @@ class ContentRate(BaseModel):
 
 
 class RateLicenseResponse(BaseModel):
+    cuid: str | None
     licenseType: str
     licensePath: str
     permissions: List[RateLicensePermission]
-    validUntil: datetime
 
 
 class RateLicensePermission(BaseModel):
